#ifndef C
#error "C not defined"
#endif

C(align)
C(upgma5)
C(msastats)
C(pprog)
C(pprog2)
C(pprogt)
C(strip_gappy)
C(strip_gappy_cols)
C(strip_gappy_rows)
C(guide_tree_join_order)
C(eadistmx)
C(eadistmx_msas)
//C(split_tree)
C(tree_subset_nodes)
C(consseq)
C(super4)
C(usorter)
C(permute_tree)
C(divide_tree)
C(qscore)
C(qscore_oldcode)
C(qscore2)
C(qscoredir)
C(eacluster)
C(derep)
C(uclust)
C(super5)
C(super6)
C(transaln)
C(hmmdump)
C(perturbhmm)
C(resample)
C(disperse)
C(efastats)
C(fa2efa)
C(colscore_efa)
C(qscore_efa)
C(efa_bestconf)
C(efa_bestcols)
C(trimtoref)
C(trimtoref_efa)
C(efa_explode)
C(relabel)
C(addconfseq)
C(labels2randomchaintree)
C(maxcc)
C(letterconf)
C(letterconf_html)
C(make_a2m)
C(make_a2m_refseq)
C(eesort)
C(strip_anchors)
C(profalign)
C(profseq)
C(protdists)
C(uclustpd)
C(uclustpd2)
C(searchpd)
C(build_guide_tree)
C(test_malloc)
C(upgma5_msa)
C(pprog_tree)
C(test)
C(build_prof3)
C(profprof3)
C(muscle3)
C(make_substmx)
C(bench)
C(bench_blosums)
C(sweep)
C(spatter)
C(msaselfscore3)
C(batch)
C(m3ensemble)
C(m3select)
C(m3refine)
C(addletterconfseq)
C(cmp_msa)
C(cmp_ref_msas)
C(squeeze_inserts)
C(newbench_selectpfams)
C(newbench_pfamgroups)
C(mustang_core)
//C(align_mega)
C(test_mega)
C(shrub)
C(super7)
//C(super7_mega)
C(swdistmx)
C(transalnref)
C(mega_msas)
C(masm_train)
C(sw)
C(swmasm)
C(swmasm_seq)
C(masm_stats)
C(mega2)
C(test_sw_aa)
C(test_sw_mm)
C(swtest)
C(swtestmm)
C(swsimple2)

#undef C
